summaryrefslogtreecommitdiffstats
path: root/kmail/objecttreeparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/objecttreeparser.h')
-rw-r--r--kmail/objecttreeparser.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmail/objecttreeparser.h b/kmail/objecttreeparser.h
index 5cfe1d0e..2325b242 100644
--- a/kmail/objecttreeparser.h
+++ b/kmail/objecttreeparser.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -151,7 +151,7 @@ namespace KMail {
mIncludeSignatures = include;
}
- // Controls whether Toltec invitations are displayed in their raw form or as a tqreplacement text,
+ // Controls whether Toltec invitations are displayed in their raw form or as a replacement text,
// which is used in processToltecMail().
void setShowRawToltecMail( bool showRawToltecMail ) { mShowRawToltecMail = showRawToltecMail; }
bool showRawToltecMail() const { return mShowRawToltecMail; }
@@ -169,13 +169,13 @@ namespace KMail {
KMail::CSSHelper * cssHelper() const { return mCSSHelper; }
/** Parse beginning at a given node and recursively parsing
- the children of that node and it's next sibling. */
+ the tqchildren of that node and it's next sibling. */
// Function is called internally by "parseMsg(KMMessage* msg)"
- // and it will be tqreplaced once KMime is alive.
+ // and it will be replaced once KMime is alive.
void parseObjectTree( partNode * node );
private:
/** Standard children handling a.k.a. multipart/mixed (w/o
kroupware hacks) */
void stdChildHandling( partNode * child );
@@ -193,7 +193,7 @@ namespace KMail {
* Setting this to false is useful for encapsulated messages, as we
* do not want the text in those to appear in the editor
*/
- // Function will be tqreplaced once KMime is alive.
+ // Function will be replaced once KMime is alive.
void insertAndParseNewChildNode( partNode & node,
const char * content,
const char * cntDesc,
@@ -252,11 +252,11 @@ namespace KMail {
*/
bool processToltecMail( partNode * node );
/** Checks whether @p str tqcontains external references. To be precise,
we only check whether @p str tqcontains 'xxx="http[s]:' where xxx is
not href. Obfuscated external references are ignored on purpose.
*/
- static bool tqcontainsExternalReferences( const TQCString & str );
+ static bool containsExternalReferences( const TQCString & str );
public:// (during refactoring)
@@ -169,13 +169,13 @@ namespace KMail {
void parseObjectTree( partNode * node );
private:
- /** Standard children handling a.k.a. multipart/mixed (w/o
+ /** Standard tqchildren handling a.k.a. multipart/mixed (w/o
kroupware hacks) */
void stdChildHandling( partNode * child );
@@ -252,11 +252,11 @@ namespace KMail {
*/
bool processToltecMail( partNode * node );
- /** Checks whether @p str tqcontains external references. To be precise,
+ /** Checks whether @p str contains external references. To be precise,
we only check whether @p str tqcontains 'xxx="http[s]:' where xxx is
not href. Obfuscated external references are ignored on purpose.